@@ -33,8 +33,13 @@ from ._reporting import EXPERIMENT_CREATED, EXPERIMENT_CREATION_FAILED
 from ._typing import Any, Dict, Optional
 from .api import API, APIExperiment
 from .comet import Streamer, format_url, generate_guid, is_valid_experiment_key
-from .config import get_global_experiment  # noqa
-from .config import get_api_key, get_config, get_previous_experiment, get_ws_url
+from .config import (  # noqa
+    get_api_key,
+    get_config,
+    get_global_experiment,
+    get_previous_experiment,
+    get_ws_url,
+)
 from .connection import (
     INITIAL_BEAT_DURATION,
     RestServerConnection,
@@ -142,6 +147,7 @@ class Experiment(BaseExperiment):
         log_env_cpu=True,
         display_summary_level=1,
         optimizer_data=None,
+        auto_weight_logging=False,
     ):
         """
         Creates a new experiment on the Comet.ml frontend.
@@ -154,7 +160,7 @@ class Experiment(BaseExperiment):
             log_graph: Default(True) - allows you to enable/disable automatic computation graph logging.
             auto_param_logging: Default(True) - allows you to enable/disable hyper parameters logging
             auto_metric_logging: Default(True) - allows you to enable/disable metrics logging
-            parse_args: Default(True) - allows you to enable/disable automatic parsing of CLI arguments
+            auto_weight_logging: Default(False) - allows you to enable/disable histogram logging for bias and weights
             auto_output_logging: Default("default") - allows you to select
                 which output logging mode to use. You can pass `"native"`
                 which will log all output even when it originated from a C
@@ -164,6 +170,7 @@ class Experiment(BaseExperiment):
                 `"default"` which will detect your environment and deactivate
                 the output logging for IPython and Jupyter environment and
                 sets `"native"` in the other cases.
+            parse_args: Default(True) - allows you to enable/disable automatic parsing of CLI arguments
             log_env_details: Default(True) - log various environment
                 information in order to identify where the script is running
             log_env_gpu: Default(True) - allow you to enable/disable the
@@ -216,13 +223,14 @@ class Experiment(BaseExperiment):
             display_summary_level=display_summary_level,
             log_env_cpu=log_env_cpu,
             optimizer_data=optimizer_data,
+            auto_weight_logging=auto_weight_logging,
         )
 
         self.ws_connection = None
         self.connection = None  # type: Optional[RestServerConnection]
         self.rest_api_client = None
 
-        if disabled is not True:
+        if self.disabled is not True:
             self._start()
 
             if self.alive is True:
@@ -719,7 +727,7 @@ class ExistingExperiment(Experiment):
             log_graph: Default(False) - allows you to enable/disable automatic computation graph logging.
             auto_param_logging: Default(True) - allows you to enable/disable hyper parameters logging
             auto_metric_logging: Default(True) - allows you to enable/disable metrics logging
-            parse_args: Default(False) - allows you to enable/disable automatic parsing of CLI arguments
+            auto_weight_logging: Default(False) - allows you to enable/disable hisogram logging for bias and weights
             auto_output_logging: Default("default") - allows you to select
                 which output logging mode to use. You can pass `"native"`
                 which will log all output even when it originated from a C
@@ -729,6 +737,7 @@ class ExistingExperiment(Experiment):
                 `"default"` which will detect your environment and deactivate
                 the output logging for IPython and Jupyter environment and
                 sets `"native"` in the other cases.
+            parse_args: Default(False) - allows you to enable/disable automatic parsing of CLI arguments
             log_env_details: Default(False) - log various environment
                 information in order to identify where the script is running
             log_env_gpu: Default(False) - allow you to enable/disable the
@@ -789,19 +798,23 @@ class ExistingExperiment(Experiment):
 
         ## Defaults for ExistingExperiment:
         ## For now, don't destroy previous Experiment information by default:
-        for key in [
-            "log_code",
-            "log_graph",
-            "parse_args",
-            "log_env_details",
-            "log_git_metadata",
-            "log_git_patch",
-            "log_env_gpu",
-            "log_env_cpu",
-            "log_env_host",
+
+        for (key, config_name, default) in [
+            ("log_code", "comet.auto_log.code", False),
+            ("log_graph", "comet.auto_log.graph", False),
+            ("parse_args", "comet.auto_log.cli_arguments", False),
+            ("log_env_details", "comet.auto_log.env_details", False),
+            ("log_git_metadata", "comet.auto_log.git_metadata", False),
+            ("log_git_patch", "comet.auto_log.git_patch", False),
+            ("log_env_gpu", "comet.auto_log.env_gpu", False),
+            ("log_env_cpu", "comet.auto_log.env_cpu", False),
+            ("log_env_host", "comet.auto_log.env_host", False),
         ]:
-            if key not in kwargs:
-                kwargs[key] = False
+            if key not in kwargs or kwargs[key] is None:
+                kwargs[key] = self.config.get_bool(
+                    None, config_name, default, not_set_value=None
+                )
+
         super(ExistingExperiment, self).__init__(api_key, **kwargs)
 
     def _get_experiment_key(self):
