@@ -33,22 +33,31 @@ from os.path import basename, splitext
 from six.moves.queue import Empty, Queue
 from six.moves.urllib.parse import urlencode, urlsplit, urlunsplit
 
-from ._logging import OS_PACKAGE_MSG_SENDING_ERROR, STREAMER_WAIT_FOR_FINISH_FAILED
 from ._reporting import ON_EXIT_DIDNT_FINISH_UPLOAD_SDK
-from ._typing import List, Optional, Tuple, Union
+from ._typing import List, Optional, Tuple
 from .config import ADDITIONAL_STREAMER_UPLOAD_TIMEOUT, DEFAULT_STREAMER_MSG_TIMEOUT
 from .connection import format_messages_for_ws
 from .exceptions import CometRestApiException
-from .file_uploader import upload_file_like_thread, upload_file_thread
+from .file_uploader import is_user_text, upload_file_like_thread, upload_file_thread
 from .json_encoder import NestedEncoder
+from .logging_messages import (
+    CLOUD_DETAILS_MSG_SENDING_ERROR,
+    MODEL_GRAPH_MSG_SENDING_ERROR,
+    OS_PACKAGE_MSG_SENDING_ERROR,
+    STREAMER_WAIT_FOR_FINISH_FAILED,
+)
 from .messages import (
+    BaseMessage,
     CloseMessage,
+    CloudDetailsMessage,
     Message,
+    ModelGraphMessage,
     OsPackagesMessage,
+    SystemDetailsMessage,
     UploadFileMessage,
     UploadInMemoryMessage,
 )
-from .utils import wait_for_empty
+from .utils import data_to_fp, wait_for_empty, write_file_like_to_tmp_file
 
 DEBUG = False
 LOGGER = logging.getLogger(__name__)
@@ -106,7 +115,7 @@ class BaseStreamer(threading.Thread):
         pass
 
     def getn(self, n):
-        # type: (int) -> Optional[List[Tuple[Union[Message, UploadFileMessage, UploadInMemoryMessage, OsPackagesMessage, CloseMessage], int]]]
+        # type: (int) -> Optional[List[Tuple[BaseMessage, int]]]
         """
         Pops n messages from the queue.
         Args:
@@ -234,6 +243,12 @@ class Streamer(BaseStreamer):
                             self._process_ws_message(message, offset)
                         elif isinstance(message, OsPackagesMessage):
                             self._process_os_package_message(message)
+                        elif isinstance(message, ModelGraphMessage):
+                            self._process_model_graph_message(message)
+                        elif isinstance(message, SystemDetailsMessage):
+                            self._process_system_details_message(message)
+                        elif isinstance(message, CloudDetailsMessage):
+                            self._process_cloud_details_message(message)
                         else:
                             raise ValueError("Unkown message type %r", message)
 
@@ -317,6 +332,68 @@ class Streamer(BaseStreamer):
         except Exception:
             LOGGER.debug("Error sending os_packages message", exc_info=True)
 
+    def _process_model_graph_message(self, message):
+        # type: (ModelGraphMessage) -> None
+        try:
+            self.rest_api_client.set_experiment_model_graph(
+                self.experiment_key, message.graph
+            )
+        except CometRestApiException as exc:
+            LOGGER.debug(
+                MODEL_GRAPH_MSG_SENDING_ERROR,
+                exc.response.status_code,
+                exc.response.content,
+            )
+        except Exception:
+            LOGGER.debug("Error sending model_graph message", exc_info=True)
+
+    def _process_system_details_message(self, message):
+        # type: (SystemDetailsMessage) -> None
+        try:
+            self.rest_api_client.set_experiment_system_details(
+                _os=message.os,
+                command=message.command,
+                env=message.env,
+                experiment_key=self.experiment_key,
+                hostname=message.hostname,
+                ip=message.ip,
+                machine=message.machine,
+                network_interfaces_ips=message.network_interfaces_ips,
+                os_release=message.os_release,
+                os_type=message.os_type,
+                pid=message.pid,
+                processor=message.processor,
+                python_exe=message.python_exe,
+                python_version_verbose=message.python_version_verbose,
+                python_version=message.python_version,
+                user=message.user,
+            )
+        except CometRestApiException as exc:
+            LOGGER.debug(
+                MODEL_GRAPH_MSG_SENDING_ERROR,
+                exc.response.status_code,
+                exc.response.content,
+            )
+        except Exception:
+            LOGGER.debug("Error sending model_graph message", exc_info=True)
+
+    def _process_cloud_details_message(self, message):
+        # type: (CloudDetailsMessage) -> None
+        try:
+            self.rest_api_client.set_experiment_cloud_details(
+                experiment_key=self.experiment_key,
+                provider=message.provider,
+                cloud_metadata=message.cloud_metadata,
+            )
+        except CometRestApiException as exc:
+            LOGGER.debug(
+                CLOUD_DETAILS_MSG_SENDING_ERROR,
+                exc.response.status_code,
+                exc.response.content,
+            )
+        except Exception:
+            LOGGER.debug("Error sending cloud details message", exc_info=True)
+
     def _check_heartbeat(self):
         """
         Check if we should send an heartbeat
@@ -508,10 +585,18 @@ class OfflineStreamer(BaseStreamer):
                         return message
                     elif isinstance(message, UploadFileMessage):
                         self._process_upload_message(message)
+                    elif isinstance(message, UploadInMemoryMessage):
+                        self._process_upload_in_memory_message(message)
                     elif isinstance(message, Message):
                         self._process_ws_message(message)
                     elif isinstance(message, OsPackagesMessage):
                         self._process_os_package_message(message)
+                    elif isinstance(message, ModelGraphMessage):
+                        self._process_model_graph_message(message)
+                    elif isinstance(message, SystemDetailsMessage):
+                        self._process_system_details_message(message)
+                    elif isinstance(message, CloudDetailsMessage):
+                        self._process_cloud_details_message(message)
                     else:
                         raise ValueError("Unkown message type %r", message)
 
@@ -534,10 +619,15 @@ class OfflineStreamer(BaseStreamer):
         tmpfile.close()
 
         if message.clean:
+            # TODO: Avoid un-necessary file copy by checking if the file is
+            # already at the top-level of self.tmp_di
+
             # Then move the original file to the newly create file
             shutil.move(message.file_path, tmpfile.name)
         else:
             shutil.copy(message.file_path, tmpfile.name)
+            # Mark the file to be cleaned as we copied it to our tmp dir
+            message.clean = True
 
         message.file_path = basename(tmpfile.name)
 
@@ -546,6 +636,27 @@ class OfflineStreamer(BaseStreamer):
         self.file.write(compact_json(data) + "\n")
         self.file.flush()
 
+    def _process_upload_in_memory_message(self, message):
+        # type: (UploadInMemoryMessage) -> None
+
+        # We need to convert the in-memory file to a file one
+        if is_user_text(message.file_like):
+            file_like = data_to_fp(message.file_like)
+        else:
+            file_like = message.file_like
+
+        tmpfile = write_file_like_to_tmp_file(file_like, self.tmp_dir)
+
+        new_message = UploadFileMessage(
+            tmpfile,
+            message.upload_type,
+            message.additional_params,
+            message.metadata,
+            clean=True,
+        )
+
+        return self._process_upload_message(new_message)
+
     def _process_ws_message(self, message):
         # type: (Message) -> None
         msg_json = message._non_null_dict()
@@ -562,6 +673,30 @@ class OfflineStreamer(BaseStreamer):
         self.file.write(compact_json(data) + "\n")
         self.file.flush()
 
+    def _process_model_graph_message(self, message):
+        # type: (ModelGraphMessage) -> None
+        msg_json = message._non_null_dict()
+
+        data = {"type": "graph", "payload": msg_json}
+        self.file.write(compact_json(data) + "\n")
+        self.file.flush()
+
+    def _process_system_details_message(self, message):
+        # type: (SystemDetailsMessage) -> None
+        msg_json = message._non_null_dict()
+
+        data = {"type": "system_details", "payload": msg_json}
+        self.file.write(compact_json(data) + "\n")
+        self.file.flush()
+
+    def _process_cloud_details_message(self, message):
+        # type: (CloudDetailsMessage) -> None
+        msg_json = message._non_null_dict()
+
+        data = {"type": "cloud_details", "payload": msg_json}
+        self.file.write(compact_json(data) + "\n")
+        self.file.flush()
+
     def wait_for_finish(self):
         """ Blocks the experiment from exiting until all data was sent to server OR 30 seconds passed."""
 
