@@ -31,7 +31,7 @@ from everett.manager import (
     parse_bool,
 )
 
-from ._typing import Any, Optional
+from ._typing import Any, Dict, Optional
 
 try:  # everett version 1.0.1 or greater
     from everett.ext.inifile import ConfigIniEnv
@@ -125,7 +125,7 @@ def generate_uppercase_key(key, namespace=None):
 class Config(object):
     def __init__(self, config_map):
         self.config_map = config_map
-        self.override = {}
+        self.override = {}  # type: Dict[str, Any]
         self.backend_override = ConfigDictEnv({})
         self.manager = ConfigManager(
             [  # User-defined overrides
@@ -158,6 +158,95 @@ class Config(object):
     def keys(self):
         return self.config_map.keys()
 
+    def get_raw(self, user_value, config_name, default=None, not_set_value=None):
+        # type: (Any, str, Optional[Any], Optional[Any]) -> Any
+        """
+        Returns the correct config value based on the following priority list:
+        * User_value if set and not None
+        * The override value from the Backend
+        * The configured value
+        * The default value passed in argument if not None
+        * The configured value default
+        """
+
+        # 1. User value
+        if user_value is not not_set_value:
+            return user_value
+
+        # 2. Override
+        if config_name in self.override:
+            override_value = self.override[config_name]
+
+            if override_value is not None:
+                return override_value
+
+        # 3. Configured value
+        config_type = self.config_map[config_name].get("type", str)
+        parser = PARSER_MAP[config_type]
+
+        # Value
+        splitted = config_name.split(".")
+
+        config_value = self.manager(
+            splitted[-1], namespace=splitted[:-1], parser=parser, raise_error=False
+        )
+
+        if config_value != NO_VALUE:
+            return config_value
+
+        else:
+            # 4. Provided default
+            if default is not None:
+                return default
+
+            # 5. Config default
+            config_default = parser(self.config_map[config_name].get("default", None))
+            return config_default
+
+    def get_string(self, user_value, config_name, default=None, not_set_value=None):
+        # type: (Any, str, Optional[str]) -> str
+        """
+        Returns the correct config value based on the following priority list:
+        * User_value if set and not None
+        * The override value from the Backend
+        * The configured value
+        * The default value passed in argument if not None
+        * The configured value default
+
+        In addition make sure the returned value is a string
+        """
+
+        value = self.get_raw(
+            user_value=user_value,
+            config_name=config_name,
+            default=default,
+            not_set_value=not_set_value,
+        )
+
+        return value
+
+    def get_bool(self, user_value, config_name, default=None, not_set_value=None):
+        # type: (Any, str, Optional[bool]) -> bool
+        """
+        Returns the correct config value based on the following priority list:
+        * User_value if set and not None
+        * The override value from the Backend
+        * The configured value
+        * The default value passed in argument if not None
+        * The configured value default
+
+        In addition make sure the returned value is a bool
+        """
+
+        value = self.get_raw(
+            user_value=user_value,
+            config_name=config_name,
+            default=default,
+            not_set_value=not_set_value,
+        )
+
+        return value
+
     def get_subsections(self):
         """
         Return the subsection config names.
@@ -376,10 +465,26 @@ CONFIG_MAP = {
     "comet.override_feature.sdk_log_env_variables": {
         "type": bool
     },  # Leave feature toggle default to None
+    # Experiment log controls:
+    "comet.auto_log.cli_arguments": {"type": bool},
+    "comet.auto_log.code": {"type": bool},
+    "comet.auto_log.disable": {"type": bool},
+    "comet.auto_log.env_cpu": {"type": bool},
+    "comet.auto_log.env_details": {"type": bool},
+    "comet.auto_log.env_gpu": {"type": bool},
+    "comet.auto_log.env_host": {"type": bool},
+    "comet.auto_log.git_metadata": {"type": bool},
+    "comet.auto_log.git_patch": {"type": bool},
+    "comet.auto_log.graph": {"type": bool},
+    "comet.auto_log.metrics": {"type": bool},
+    "comet.auto_log.output_logger": {"type": str},
+    "comet.auto_log.parameters": {"type": bool},
+    "comet.auto_log.weights": {"type": bool},
 }
 
 
 def get_config(setting=None):
+    # type: (Any) -> Config
     """
     Get a config or setting from the current config
     (os.environment or .env file).
