@@ -32,8 +32,6 @@ from six.moves.urllib.parse import urlparse
 
 LOGGER = logging.getLogger(__name__)
 
-EMPTY_BLOB = dulwich.objects.Blob.from_string(b"")
-
 
 def _patched_path_to_tree_path(repopath, path):
     """Convert a path to a path usable in e.g. an index.
@@ -160,110 +158,6 @@ def get_repo_name(origin_url):
     return repo_name
 
 
-def patched_gen_diff_header(paths, modes, shas):
-    """Write a blob diff header.
-
-    :param paths: Tuple with old and new path
-    :param modes: Tuple with old and new modes
-    :param shas: Tuple with old and new shas
-
-    PATCHED: see https://github.com/dulwich/dulwich/issues/642 for explanation
-    Also fix path support as patch are not cleaned anymore
-    """
-    (old_path, new_path) = paths
-    (old_mode, new_mode) = modes
-    (old_sha, new_sha) = shas
-    shortid = dulwich.patch.shortid
-    if old_path is None and new_path is not None:
-        old_path = new_path
-    if new_path is None and old_path is not None:
-        new_path = old_path
-    old_path = dulwich.patch.patch_filename(old_path, b"a")
-    new_path = dulwich.patch.patch_filename(new_path, b"b")
-    yield b"diff --git " + old_path + b" " + new_path + b"\n"
-
-    if old_mode != new_mode:
-        if new_mode is not None:
-            if old_mode is not None:
-                yield ("old file mode %o\n" % old_mode).encode("ascii")
-
-            yield ("new file mode %o\n" % new_mode).encode("ascii")
-
-        else:
-            yield ("deleted file mode %o\n" % old_mode).encode("ascii")
-
-    yield b"index " + shortid(old_sha) + b".." + shortid(new_sha)
-
-    if new_mode is not None and old_mode is not None:
-        yield (" %o" % new_mode).encode("ascii")
-
-    yield b"\n"
-
-
-def patched_write_object_diff(f, store, old_file, new_file, diff_binary=False):
-    """Write the diff for an object.
-
-    :param f: File-like object to write to
-    :param store: Store to retrieve objects from, if necessary
-    :param old_file: (path, mode, hexsha) tuple
-    :param new_file: (path, mode, hexsha) tuple
-    :param diff_binary: Whether to diff files even if they
-        are considered binary files by is_binary().
-
-    :note: the tuple elements should be None for nonexistent files
-
-    PATCHED: Don't use /dev/null in header to respect Git format
-    """
-    (old_path, old_mode, old_id) = old_file
-    (new_path, new_mode, new_id) = new_file
-    patched_old_path = dulwich.patch.patch_filename(old_path, b"a")
-    patched_new_path = dulwich.patch.patch_filename(new_path, b"b")
-
-    def content(mode, hexsha):
-        if hexsha is None:
-            return dulwich.objects.Blob.from_string(b"")
-        elif dulwich.objects.S_ISGITLINK(mode):
-            return dulwich.objects.Blob.from_string(
-                b"Subproject commit " + hexsha + b"\n"
-            )
-        else:
-            return store[hexsha]
-
-    def lines(content):
-        if not content:
-            return []
-        else:
-            return content.splitlines()
-
-    f.writelines(
-        patched_gen_diff_header(
-            (old_path, new_path), (old_mode, new_mode), (old_id, new_id)
-        )
-    )
-    old_content = content(old_mode, old_id)
-    new_content = content(new_mode, new_id)
-    if not diff_binary and (
-        dulwich.patch.is_binary(old_content.data)
-        or dulwich.patch.is_binary(new_content.data)
-    ):
-        f.write(
-            b"Binary files "
-            + patched_old_path
-            + b" and "
-            + patched_new_path
-            + b" differ\n"
-        )
-    else:
-        f.writelines(
-            dulwich.patch.unified_diff(
-                lines(old_content),
-                lines(new_content),
-                patched_old_path,
-                patched_new_path,
-            )
-        )
-
-
 class OverrideObjectStore(object):
     def __init__(self, repo_object_store):
         self.repo_object_store = repo_object_store
@@ -373,7 +267,7 @@ def get_git_patch(repo, unstaged=True):
     for (oldpath, newpath), (oldmode, newmode), (oldsha, newsha) in sorted(
         final_changes, key=key
     ):
-        patched_write_object_diff(
+        dulwich.patch.write_object_diff(
             diff, store, (oldpath, oldmode, oldsha), (newpath, newmode, newsha)
         )
 
