@@ -14,9 +14,12 @@
 
 import logging
 
+import wrapt
+
 from .._logging import check_module
 
 LOGGER = logging.getLogger(__name__)
+SCALE_LOSS_ORIGINAL = None
 
 
 def tensor_backward(experiment, original, result, *args, **kwargs):
@@ -26,14 +29,17 @@ def tensor_backward(experiment, original, result, *args, **kwargs):
             experiment.curr_step = 0
         else:
             experiment.curr_step += 1
-        if experiment.log_graph and not experiment.disabled_monkey_patching:
+        if experiment.log_graph:
             model = experiment._storage["torch"].get("model", None)
             if experiment.curr_step == 0 and model is not None:
-                experiment._set_model_graph(str(model), framework="pytorch")
-        if experiment.auto_metric_logging and not experiment.disabled_monkey_patching:
+                experiment._set_model_graph(model, framework="pytorch")
+        if experiment.auto_metric_logging:
             ## Throttle report to every 10 batch updates:
             if experiment.curr_step % 10 == 0:
-                loss = args[0]
+                if SCALE_LOSS_ORIGINAL is not None:
+                    loss = SCALE_LOSS_ORIGINAL
+                else:
+                    loss = args[0]
                 if len(loss.data.shape) == 0:
                     experiment._log_metric(
                         "loss",
@@ -63,6 +69,30 @@ def model_constructor(experiment, original, *args, **kwargs):
         LOGGER.info("Failed to run Module.__init__ logger", exc_info=True)
 
 
+class CallableWrapper(wrapt.ObjectProxy):
+    def __init__(self, wrapped, original_loss):
+        super(CallableWrapper, self).__init__(wrapped)
+        self.original_loss = original_loss
+
+    def __enter__(self, *args, **kwargs):
+        return_value = self.__wrapped__.__enter__(*args, **kwargs)
+
+        global SCALE_LOSS_ORIGINAL
+        SCALE_LOSS_ORIGINAL = self.original_loss
+
+        return return_value
+
+    def __exit__(self, *args, **kwargs):
+        global SCALE_LOSS_ORIGINAL
+        SCALE_LOSS_ORIGINAL = None
+
+        return self.__wrapped__.__exit__(*args, **kwargs)
+
+
+def scale_loss_hook(experiment, original, return_value, original_loss, *args, **kwargs):
+    return CallableWrapper(return_value, original_loss)
+
+
 def patch(module_finder):
     ## For testing:
     check_module("torch")
@@ -74,5 +104,7 @@ def patch(module_finder):
         "torch.nn.modules.module", "Module.__init__", model_constructor
     )
 
+    module_finder.register_after("apex.amp.handle", "scale_loss", scale_loss_hook)
+
 
 check_module("torch")
