@@ -20,7 +20,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 def xgboost_train(experiment, original, return_value, *args, **kwargs):
-    if experiment.auto_param_logging and not experiment.disabled_monkey_patching:
+    if experiment.auto_param_logging:
         # Log XGBoost parameters
         if not experiment._storage["xgboost"].get("parameter_set", False):
             params = {key: value for key, value in args[0].items() if value is not None}
