@@ -97,6 +97,7 @@ class OfflineExperiment(BaseExperiment):
         display_summary=None,  # type: Optional[bool]
         log_env_cpu=True,  # type: Optional[bool]
         display_summary_level=None,  # type: Optional[int]
+        auto_weight_logging=False,  # type: Optional[bool]
     ):
         # type: (...) -> None
         """
@@ -109,7 +110,7 @@ class OfflineExperiment(BaseExperiment):
             log_graph: Default(True) - allows you to enable/disable automatic computation graph logging.
             auto_param_logging: Default(True) - allows you to enable/disable hyper parameters logging
             auto_metric_logging: Default(True) - allows you to enable/disable metrics logging
-            parse_args: Default(True) - allows you to enable/disable automatic parsing of CLI arguments
+            auto_weight_logging: Default(False) - allows you to enable/disable automatic histogram logging of biases and weights
             auto_output_logging: Default("default") - allows you to select
                 which output logging mode to use. You can pass `"native"`
                 which will log all output even when it originated from a C
@@ -119,6 +120,7 @@ class OfflineExperiment(BaseExperiment):
                 `"default"` which will detect your environment and deactivate
                 the output logging for IPython and Jupyter environment and
                 sets `"native"` in the other cases.
+            parse_args: Default(True) - allows you to enable/disable automatic parsing of CLI arguments
             log_env_details: Default(True) - log various environment
                 information in order to identify where the script is running
             log_env_gpu: Default(True) - allow you to enable/disable the
@@ -161,36 +163,36 @@ class OfflineExperiment(BaseExperiment):
         self.stop_time = None
 
         super(OfflineExperiment, self).__init__(
-            project_name,
-            workspace,
-            log_code,
-            log_graph,
-            auto_param_logging,
-            auto_metric_logging,
-            parse_args,
-            auto_output_logging,
-            log_env_details,
-            log_git_metadata,
-            log_git_patch,
-            disabled,
-            log_env_gpu,
-            log_env_host,
-            display_summary,
-            log_env_cpu,
-            display_summary_level,
+            project_name=project_name,
+            workspace=workspace,
+            log_code=log_code,
+            log_graph=log_graph,
+            auto_param_logging=auto_param_logging,
+            auto_metric_logging=auto_metric_logging,
+            parse_args=parse_args,
+            auto_output_logging=auto_output_logging,
+            log_env_details=log_env_details,
+            log_git_metadata=log_git_metadata,
+            log_git_patch=log_git_patch,
+            disabled=disabled,
+            log_env_gpu=log_env_gpu,
+            log_env_host=log_env_host,
+            display_summary_level=display_summary_level,
+            log_env_cpu=log_env_cpu,
+            auto_weight_logging=auto_weight_logging,
         )
 
-        if not disabled:
+        if not self.disabled:
             # Check that the offline directory is usable
             try:
                 # Try to create the archive now
-                zipfile = self._get_offline_archive(offline_directory, self.id)
+                zipfile = self._get_offline_archive(self.offline_directory, self.id)
                 # Close the file handle, it will be reopened later
                 zipfile.close()
             except (OSError, IOError) as exc:
                 raise InvalidOfflineDirectory(self.offline_directory, str(exc))
 
-        if disabled is not True:
+        if self.disabled is not True:
             if api_key is not None:
                 LOGGER.warning(
                     "api_key was given, but is ignored in OfflineExperiment(); remember to set when you upload"
