@@ -90,15 +90,22 @@ class Optimizer(object):
         >>> opt = Optimizer("73745463463")
 
         # A filename to a optimizer config file:
-        >>> opt = Optimizer("optimizer.config")
-
-        # With arguments for Experiment:
-        >>> opt = Optimizer(
-        ...     "optimizer.config",
-        ...     project_name="my-project",
-        ...     auto_metric_logging=False,
-        ... )
+        >>> opt = Optimizer("/tmp/mlhacker/optimizer.config")
         ```
+
+    To pass arguments to the `Experiment` constructor, pass them into the
+    `opt.get_experiments()` call, like so:
+
+    ```python
+    >>> opt = Optimizer("/tmp/mlhacker/optimizer.config")
+    >>> for experiment in opt.get_experiments(
+    ...     project_name="my-project",
+    ...     auto_metric_logging=False,
+    ... ):
+    ...     loss = fit(model)
+    ...     experiment.log_metric("loss", loss")
+    ...     experiment.end()
+    ```
     """
 
     def __init__(
