@@ -15,14 +15,12 @@
 from __future__ import print_function
 
 import calendar
-import functools
 import getpass
 import io
 import json
 import logging
 import math
 import numbers
-import operator
 import os
 import os.path
 import random
@@ -1180,7 +1178,11 @@ class ConfusionMatrix(object):
         # Example all cells that have items (reuse from cache/other cells if possible):
         for key in examples:
             x, y = key
-            self._example_from_list(examples[key], x, y, **kwargs)
+            if self.selected is not None:
+                if x in self.selected and y in self.selected:
+                    self._example_from_list(examples[key], x, y, **kwargs)
+            else:
+                self._example_from_list(examples[key], x, y, **kwargs)
 
     def to_json(self):
         """
@@ -1300,10 +1302,14 @@ class Histogram(object):
         Args:
             start: float (optional), value of start range. Default 1e-12
             stop: float (optional), value of stop range. Default 1e20
-            step: float (optional), value of step. Greater than one creates an
-                exponentially-distributed set of bins. Default 1.1
+            step: float (optional), value of step. Creates an
+                exponentially-distributed set of bins. Must be greater
+                than 1.0. Default 1.1
             offset: float (optional), center of distribution. Default is zero.
         """
+        if step <= 1.0:
+            raise ValueError("Histogram step must be greater than 1.0")
+
         self.start = start
         self.stop = stop
         self.step = step
@@ -1343,7 +1349,7 @@ class Histogram(object):
                 to count
             counts: a list of counts for each value in values. Triggers
                 special mode for conversion from Tensorboard
-                saved format.
+                saved format. Assumes values are in order (min to max).
             max_skip_count: int, (optional) maximum number of empty
                 cells that triggers a binary search.
 
@@ -1361,7 +1367,7 @@ class Histogram(object):
         if len(values) == 0:
             return
 
-        values = flatten(values)
+        values = fast_flatten(values)
 
         # Sort for speed of inserts
         if counts is None:
@@ -1923,24 +1929,69 @@ def shape(data):
             return []
 
 
-def flatten(values):
+def lazy_flatten(iterable):
+    if hasattr(iterable, "flatten"):
+        iterable = iterable.flatten()
+    iterator, sentinel, stack = iter(iterable), object(), []
+    while True:
+        value = next(iterator, sentinel)
+        if value is sentinel:
+            if not stack:
+                break
+            iterator = stack.pop()
+        elif isinstance(value, (numbers.Number, six.string_types)):
+            yield value
+        else:
+            if hasattr(value, "flatten"):
+                value = value.flatten()
+            try:
+                new_iterator = iter(value)
+            except TypeError:
+                yield value
+            else:
+                stack.append(iterator)
+                iterator = new_iterator
+
+
+def flatten(items):
     """
     Given a nested list or a numpy array,
     return the data flattened.
     """
-    # Numpy arrays have an optimized method of flattening:
-    if hasattr(values, "flatten"):
-        values = values.flatten()
-    else:
-        # Otherwise, we try to recursively flatten via functools.reduce:
+    if isinstance(items, (numbers.Number, six.string_types)):
+        return items
+    return list(lazy_flatten(items))
+
+
+def fast_flatten(items):
+    """
+    Given a nested list or a numpy array,
+    return the data flattened.
+    """
+    if isinstance(items, (numbers.Number, six.string_types)):
+        return items
+
+    if HAS_NUMPY:
         try:
-            values = functools.reduce(
-                operator.iconcat, [flatten(value) for value in values], []
-            )
-        except TypeError:
-            # Otherwise, assume that it is already flat:
-            pass
-    return values
+            # Vector, Matrix conversion:
+            items = numpy.array(items, dtype=float)
+            return items.reshape(-1).tolist()
+        except Exception:
+            try:
+                # Uneven conversion, 2 deep:
+                items = numpy.array([numpy.array(item) for item in items], dtype=float)
+                return items.reshape(-1).tolist()
+            except Exception:
+                # Fall through
+                LOGGER.debug(
+                    "numpy unable to convert items in fast_flatten", exc_info=True
+                )
+
+    else:
+        log_once_at_level(
+            logging.INFO, "numpy not installed; using a slower flatten",
+        )
+    return flatten(items)
 
 
 def convert_to_list(items, dtype=None):
@@ -1990,7 +2041,7 @@ def convert_to_scalar(user_data, dtype=None):
         if hasattr(user_data, "numpy"):
             user_data = user_data.numpy()
     except Exception:
-        LOGGER.warning(
+        LOGGER.debug(
             "Failed to convert tensorflow tensor %r to numpy object",
             user_data,
             exc_info=True,
@@ -2001,7 +2052,7 @@ def convert_to_scalar(user_data, dtype=None):
         if HAS_NUMPY and isinstance(user_data, numpy.number):
             user_data = user_data.item()
     except Exception:
-        LOGGER.warning(
+        LOGGER.debug(
             "Failed to convert numpy object %r to Python scalar",
             user_data,
             exc_info=True,
@@ -2105,3 +2156,55 @@ def safe_filename(filename):
     string = str(filename).strip().replace(" ", "_")
     string = re.sub(r"(?u)[^-\w.]", "_", string)
     return re.sub(r"_+", "_", string)
+
+
+def convert_model_to_string(model):
+    # type: (Any) -> str
+    """
+    Given a model of some kind, convert to a string.
+    """
+    if type(model).__name__ == "Graph":  # Tensorflow Graph Definition
+        try:
+            from google.protobuf import json_format
+
+            graph_def = model.as_graph_def()
+            model = json_format.MessageToJson(graph_def, sort_keys=True)
+        except Exception:
+            LOGGER.warning("Failed to convert Tensorflow graph to JSON", exc_info=True)
+
+    if hasattr(model, "to_json"):
+        # First, try with sorted keys:
+        try:
+            model = model.to_json(sort_keys=True)
+        except Exception:
+            model = model.to_json()
+    elif hasattr(model, "to_yaml"):
+        model = model.to_yaml()
+
+    try:
+        return str(model)
+    except Exception:
+        LOGGER.warning("Unable to convert model to a string")
+        return "Unable to convert model to a string"
+
+
+def convert_object_to_dictionary(obj):
+    # type: (Any) -> Dict[str, str]
+    """
+    This function takes an object and turns it into
+    a dictionary. It turns all properties (including
+    computed properties) into a {property_name: string, ...}
+    dictionary.
+    """
+    dic = {}
+    for attr in dir(obj):
+        if attr.startswith("__") or attr.startswith("to_"):
+            continue
+        value = getattr(obj, attr)
+        if callable(value):
+            continue
+        try:
+            dic[attr] = str(value)
+        except Exception:
+            pass
+    return dic
